BlockchainWrapper

Struct BlockchainWrapper 

pub struct BlockchainWrapper<A>{ /* private fields */ }
Interface to be used by the actual smart contract code.

Note: contracts and the api are not mutable. They simply pass on/retrieve data to/from the protocol. When mocking the blockchain state, we use the Rc/RefCell pattern to isolate mock state mutability from the contract interface.

Implementations

Source

impl<A> BlockchainWrapper<A>

pub fn new() -> Self

Source

impl<A> BlockchainWrapper<A>

pub fn get_caller_legacy(&self) -> Address

👎Deprecated since 0.41.0: Please use method get_caller instead.
pub fn get_caller(&self) -> ManagedAddress<A>

pub fn get_sc_address_legacy(&self) -> Address

👎Deprecated since 0.41.0: Please use method get_sc_address instead.
pub fn get_sc_address(&self) -> ManagedAddress<A>

pub fn get_owner_address(&self) -> ManagedAddress<A>

pub fn check_caller_is_owner(&self)

pub fn check_caller_is_user_account(&self)

pub fn get_shard_of_address_legacy(&self, address: &Address) -> u32

👎Deprecated since 0.41.0: Please use method get_shard_of_address instead.
pub fn get_shard_of_address(&self, address: &ManagedAddress<A>) -> u32

pub fn is_smart_contract_legacy(&self, address: &Address) -> bool

👎Deprecated since 0.41.0: Please use method is_smart_contract instead.
pub fn is_smart_contract(&self, address: &ManagedAddress<A>) -> bool

pub fn get_balance_legacy(&self, address: &Address) -> BigUint<A>

👎Deprecated since 0.41.0: Please use method get_balance instead.
pub fn get_balance(&self, address: &ManagedAddress<A>) -> BigUint<A>

pub fn get_code_metadata(&self, address: &ManagedAddress<A>) -> CodeMetadata

pub fn get_code_hash(&self, address: &ManagedAddress<A>) -> ManagedBuffer<A>

pub fn is_builtin_function(&self, function_name: &ManagedBuffer<A>) -> bool

pub fn get_sc_balance( &self, token_id: impl AsRef<TokenId<A>>, nonce: u64, ) -> BigUint<A>

pub fn get_state_root_hash_legacy(&self) -> H256

👎Deprecated since 0.41.0: Please use method get_state_root_hash instead.
pub fn get_state_root_hash(&self) -> ManagedByteArray<A, 32>

pub fn get_tx_hash_legacy(&self) -> H256

👎Deprecated since 0.41.0: Please use method get_tx_hash instead.
pub fn get_tx_hash(&self) -> ManagedByteArray<A, 32>

pub fn get_gas_left(&self) -> u64

pub fn get_block_timestamp(&self) -> u64

👎Deprecated since 0.63.0: Use get_block_timestamp_seconds instead, it returns a properly typed timestamps

Block timestamp, in seconds.

pub fn get_block_timestamp_seconds(&self) -> TimestampSeconds

Block timestamp, in seconds.

pub fn get_block_timestamp_ms(&self) -> u64

👎Deprecated since 0.63.0: Use get_block_timestamp_millis instead, it returns a properly typed timestamps

Block timestamp, in milliseconds.

pub fn get_block_timestamp_millis(&self) -> TimestampMillis

Block timestamp, in milliseconds.

pub fn get_block_nonce(&self) -> u64

pub fn get_block_round(&self) -> u64

pub fn get_block_epoch(&self) -> u64

pub fn get_block_round_time_ms(&self) -> u64

👎Deprecated since 0.63.0: Use get_block_round_time_millis instead, it returns a properly typed duration

Block round time, in milliseconds.

pub fn get_block_round_time_millis(&self) -> DurationMillis

Block round time, in milliseconds.

pub fn epoch_start_block_timestamp_ms(&self) -> u64

👎Deprecated since 0.63.0: Use epoch_start_block_timestamp_millis instead, it returns a properly typed timestamps

Epoch start block timestamp, in milliseconds.

pub fn epoch_start_block_timestamp_millis(&self) -> TimestampMillis

👎Deprecated since 0.63.1: Renamed to get_epoch_start_block_timestamp_millis
pub fn get_epoch_start_block_timestamp_millis(&self) -> TimestampMillis

Epoch start block timestamp, in milliseconds.

pub fn get_epoch_start_block_nonce(&self) -> u64

pub fn epoch_start_block_nonce(&self) -> u64

👎Deprecated since 0.63.1: Renamed to get_epoch_start_block_nonce
pub fn get_epoch_start_block_round(&self) -> u64

pub fn epoch_start_block_round(&self) -> u64

👎Deprecated since 0.63.1: Renamed to get_epoch_start_block_round
pub fn get_block_random_seed_legacy(&self) -> Box<[u8; 48]>

👎Deprecated since 0.41.0: Please use method get_block_random_seed instead.
pub fn get_block_random_seed(&self) -> ManagedByteArray<A, 48>

pub fn get_prev_block_timestamp(&self) -> u64

👎Deprecated since 0.63.0: Use get_prev_block_timestamp_seconds instead, it returns a properly typed timestamps

Previous block timestamp, in seconds.

pub fn get_prev_block_timestamp_seconds(&self) -> TimestampSeconds

Previous block timestamp, in seconds.

pub fn get_prev_block_timestamp_ms(&self) -> u64

👎Deprecated since 0.63.0: Use get_prev_block_timestamp_millis instead, it returns a properly typed timestamps

Previous block timestamp, in milliseconds.

pub fn get_prev_block_timestamp_millis(&self) -> TimestampMillis

Previous block timestamp, in milliseconds.

pub fn get_prev_block_nonce(&self) -> u64

Previous block nonce.

pub fn get_prev_block_round(&self) -> u64

Previous block round.

pub fn get_prev_block_epoch(&self) -> u64

pub fn get_prev_block_random_seed_legacy(&self) -> Box<[u8; 48]>

👎Deprecated since 0.41.0: Please use method get_prev_block_random_seed instead.
pub fn get_prev_block_random_seed(&self) -> ManagedByteArray<A, 48>

pub fn get_current_esdt_nft_nonce( &self, address: &ManagedAddress<A>, token_id: &EsdtTokenIdentifier<A>, ) -> u64

pub fn get_esdt_balance( &self, address: &ManagedAddress<A>, token_id: &EsdtTokenIdentifier<A>, nonce: u64, ) -> BigUint<A>

Source

impl<A> BlockchainWrapper<A>

pub fn get_native_token(&self) -> ManagedRef<'static, A, TokenId<A>>

The native token of the given chain. It can currently only return EGLD-000000.

pub fn is_native_token(&self, token_id: &TokenId<A>) -> bool

Checks if a token is the native one on the chain. Currently only returns true for EGLD-000000.

Source

impl<A> BlockchainWrapper<A>

pub fn get_esdt_token_type( &self, address: &ManagedAddress<A>, token_id: &EgldOrEsdtTokenIdentifier<A>, nonce: u64, ) -> EsdtTokenType

pub fn get_esdt_token_data( &self, address: &ManagedAddress<A>, token_id: &EsdtTokenIdentifier<A>, nonce: u64, ) -> EsdtTokenData<A>

pub fn get_back_transfers_legacy(&self) -> BackTransfersLegacy<A>

👎Deprecated since 0.59.0: Does not handle multi-transfers properly, use get_back_transfers instead

Retrieves back-transfers from the VM, after a contract call.

Works after:

  • synchronous calls
  • asynchronous calls too, in callbacks.
pub fn get_back_transfers(&self) -> BackTransfers<A>

Retrieves all back-transfers as a collection of payments.

Covers all cases, including EGLD sent via multi-transfer.

pub fn reset_back_transfers(&self)

Clears back transfers by retrieving current back transfers and ignoring result.

pub fn get_token_attributes<T: TopDecode>( &self, token_id: &EsdtTokenIdentifier<A>, token_nonce: u64, ) -> T

Retrieves and deserializes token attributes from the SC account, with given token identifier and nonce.

pub fn is_esdt_frozen( &self, address: &ManagedAddress<A>, token_id: &EsdtTokenIdentifier<A>, nonce: u64, ) -> bool

pub fn is_esdt_paused(&self, token_id: &EsdtTokenIdentifier<A>) -> bool

pub fn is_esdt_limited_transfer( &self, token_id: &EsdtTokenIdentifier<A>, ) -> bool

pub fn get_esdt_local_roles( &self, token_id: &EsdtTokenIdentifier<A>, ) -> EsdtLocalRoleFlags

Source

impl<A> BlockchainWrapper<A>

pub fn get_cumulated_validator_rewards(&self) -> BigUint<A>

Retrieves validator rewards, as set by the protocol.

pub fn token_has_transfer_role( &self, token_identifier: EsdtTokenIdentifier<A>, ) -> bool