Module math

Module math 

Structs

LinearInterpolationInvalidValuesError
Error returned when current_in is outside the [min_in, max_in] range.

Functions

linear_interpolation
Computes a linearly interpolated output value for a given input within a known range.
weighted_average
Computes the weighted average of two values.
weighted_average_round_up
Computes the weighted average of two values, rounded up (ceiling division).