pub struct BigInt<M: ManagedTypeApi> { /* private fields */ }Implementations
Sourceimpl<M: ManagedTypeApi> BigInt<M>
impl<M: ManagedTypeApi> BigInt<M>
Sourcepub unsafe fn new_uninit() -> Self
pub unsafe fn new_uninit() -> Self
Creates a new object, without initializing it.
Safety
The value needs to be initialized after creation, otherwise the VM will halt the first time the value is attempted to be read.
Panic / unwind safety
If the caller unwinds (panics) before the returned value is fully initialized, the
BigInt is dropped normally — which issues a drop_big_int call for an uninitialized
handle. This may corrupt the VM handle table. Callers must ensure initialization
completes before any panic can occur.
Sourcepub unsafe fn new_init_handle<F>(init_fn: F) -> Selfwhere
F: FnOnce(M::BigIntHandle),
pub unsafe fn new_init_handle<F>(init_fn: F) -> Selfwhere
F: FnOnce(M::BigIntHandle),
Creates a new object and initializes it via a closure that receives the raw handle.
Safety
The closure init_fn must fully initialize the value behind the handle before returning.
Panic / unwind safety
If init_fn unwinds (panics), the partially-constructed BigInt is leaked — its
destructor is not called. This means no drop_big_int call will be issued for the
allocated handle, which may leave the VM handle table in an inconsistent state.
Callers must ensure that init_fn does not panic.
Sourceimpl<M: ManagedTypeApi> BigInt<M>
impl<M: ManagedTypeApi> BigInt<M>
pub fn zero() -> Self
pub fn to_i64(&self) -> Option<i64>
pub fn overwrite_i64(&mut self, value: i64)
pub fn from_signed_bytes_be(bytes: &[u8]) -> Self
pub fn to_signed_bytes_be(&self) -> BoxedBytes
pub fn from_signed_bytes_be_buffer(managed_buffer: &ManagedBuffer<M>) -> Self
pub fn to_signed_bytes_be_buffer(&self) -> ManagedBuffer<M>
Sourceimpl<M: ManagedTypeApi> BigInt<M>
impl<M: ManagedTypeApi> BigInt<M>
pub fn from_biguint(sign: Sign, unsigned: BigUint<M>) -> Self
Sourcepub fn to_parts(self) -> (Sign, BigUint<M>)
pub fn to_parts(self) -> (Sign, BigUint<M>)
Convert this BigInt into its Sign and BigUint magnitude,
the reverse of BigInt::from_biguint.
Sourcepub unsafe fn into_big_uint_unchecked(self) -> BigUint<M>
pub unsafe fn into_big_uint_unchecked(self) -> BigUint<M>
Converts to an unsigned BigUint, without performing any checks.
Safety
If the number is negative, undefined behavior might occur further down the execution.
Sourcepub fn into_big_uint(self) -> ManagedOption<M, BigUint<M>>
pub fn into_big_uint(self) -> ManagedOption<M, BigUint<M>>
Converts this BigInt into a BigUint, if it’s not negative.
Sourceimpl<M: ManagedTypeApi> BigInt<M>
impl<M: ManagedTypeApi> BigInt<M>
pub fn pow(&self, exp: u32) -> Self
Sourcepub fn into_proportion(self, part: i64, total: i64) -> Self
pub fn into_proportion(self, part: i64, total: i64) -> Self
Sourcepub fn proportion(&self, part: i64, total: i64) -> Self
pub fn proportion(&self, part: i64, total: i64) -> Self
Sourcepub fn to_display(&self) -> ManagedBuffer<M>
pub fn to_display(&self) -> ManagedBuffer<M>
Creates a managed buffer containing the textual representation of the number.