pub struct BigUint<M: ManagedTypeApi> { /* private fields */ }Expand description
A big, unsigned number.
Guaranteed to never be negative by construction and guarded operations.
Implementations
Sourceimpl<M: ManagedTypeApi> BigUint<M>
impl<M: ManagedTypeApi> BigUint<M>
Sourcepub unsafe fn new_unchecked(bi: BigInt<M>) -> Self
pub unsafe fn new_unchecked(bi: BigInt<M>) -> Self
Creates a new BigUint from a BigInt without checking invariants.
Safety
The value needs to be >= 0, otherwise the invariant is broken and subtle bugs can appear.
Sourcepub unsafe fn new_uninit() -> Self
pub unsafe fn new_uninit() -> Self
Creates a new object, without initializing it.
Safety
The value needs to be initialized after creation, otherwise the VM will halt the first time the value is attempted to be read.
pub fn as_big_int(&self) -> &BigInt<M>
pub fn into_big_int(self) -> BigInt<M>
Sourcepub fn into_non_zero(self) -> Option<NonZeroBigUint<M>>
pub fn into_non_zero(self) -> Option<NonZeroBigUint<M>>
Sourcepub fn into_non_zero_or_panic(self) -> NonZeroBigUint<M>
pub fn into_non_zero_or_panic(self) -> NonZeroBigUint<M>
Sourceimpl<M: ManagedTypeApi> BigUint<M>
More conversions here.
impl<M: ManagedTypeApi> BigUint<M>
More conversions here.
pub fn zero() -> Self
pub fn zero_ref() -> ManagedRef<'static, M, BigUint<M>>
pub fn to_u64(&self) -> Option<u64>
pub fn overwrite_u64(&mut self, value: u64)
pub fn from_bytes_be(bytes: &[u8]) -> Self
pub fn to_bytes_be(&self) -> BoxedBytes
pub fn from_bytes_be_buffer(managed_buffer: &ManagedBuffer<M>) -> Self
pub fn to_bytes_be_buffer(&self) -> ManagedBuffer<M>
Sourceimpl<M: ManagedTypeApi> BigUint<M>
impl<M: ManagedTypeApi> BigUint<M>
pub fn sqrt(&self) -> Self
pub fn pow(&self, exp: u32) -> Self
Sourcepub fn log2_floor(&self) -> Option<u32>
pub fn log2_floor(&self) -> Option<u32>
The whole part of the base-2 logarithm.
Obtained by counting the significant bits. More specifically, the log2 floor is the position of the most significant bit minus one.
Will return None for the number zero (the logarithm in this case would approach -inf).
Sourcepub fn into_proportion(self, part: u64, total: u64) -> Self
pub fn into_proportion(self, part: u64, total: u64) -> Self
Calculates proportion of this value, consuming self.
Arguments
part- The numerator value (e.g., 1000 for 1% when total is 100000)total- The denominator value for the ratio calculation (e.g., 100 for percentage, 100000 for basis points)
Returns
The proportional amount as BigUint (self * part / total)
Notes
Both part and total must be at most i64::MAX. Values exceeding this limit will cause an error.
Example
let amount = BigUint::from(1000u32);
let result = amount.into_proportion(5u32, 100u32); // 5/100 of 1000 = 50Sourcepub fn proportion(&self, part: u64, total: u64) -> Self
pub fn proportion(&self, part: u64, total: u64) -> Self
Calculates proportion of this value.
Arguments
part- The numerator value (e.g., 1000 for 1% when total is 100000)total- The denominator value for the ratio calculation (e.g., 100 for percentage, 100000 for basis points)
Returns
The proportional amount as BigUint (self * part / total)
Notes
Both part and total must be at most i64::MAX. Values exceeding this limit will cause an error.
Example
let amount = BigUint::from(1000u32);
let result = amount.proportion(5u32, 100u32); // 5/100 of 1000 = 50Sourcepub fn ln(&self) -> Option<ManagedDecimal<M, LnDecimals>>
pub fn ln(&self) -> Option<ManagedDecimal<M, LnDecimals>>
Natural logarithm of a number.
Returns None for 0.
Sourceimpl<M: ManagedTypeApi> BigUint<M>
impl<M: ManagedTypeApi> BigUint<M>
Sourcepub fn to_display(&self) -> ManagedBuffer<M>
pub fn to_display(&self) -> ManagedBuffer<M>
Creates to a managed buffer containing the textual representation of the number.