pub struct ContractCallNoPayment<SA, OriginalResult>where
SA: CallTypeApi + 'static,{
pub to: ManagedAddress<SA>,
pub function_call: FunctionCall<SA>,
pub explicit_gas_limit: u64,
/* private fields */
}Please use the unified transaction syntax instead.
Holds metadata for calling another contract, without payments.
Proxies generally create contract calls of this type (unless there are payment arguments in the endpoint - but these are mostly obsolete now).
It is also the basis for all other contract call types, all of them contain this one.
Fields
to: ManagedAddress<SA>Please use the unified transaction syntax instead.
function_call: FunctionCall<SA>Please use the unified transaction syntax instead.
explicit_gas_limit: u64Please use the unified transaction syntax instead.
Implementations
Sourceimpl<SA, OriginalResult> ContractCallNoPayment<SA, OriginalResult>where
SA: CallTypeApi + 'static,
impl<SA, OriginalResult> ContractCallNoPayment<SA, OriginalResult>where
SA: CallTypeApi + 'static,
pub fn new<N: Into<ManagedBuffer<SA>>>( to: ManagedAddress<SA>, endpoint_name: N, ) -> Self
Sourcepub fn with_egld_transfer(
self,
egld_amount: BigUint<SA>,
) -> ContractCallWithEgld<SA, OriginalResult>
pub fn with_egld_transfer( self, egld_amount: BigUint<SA>, ) -> ContractCallWithEgld<SA, OriginalResult>
Sets payment to be EGLD transfer.
Sourcepub fn with_esdt_transfer<P: Into<EsdtTokenPayment<SA>>>(
self,
payment: P,
) -> ContractCallWithMultiEsdt<SA, OriginalResult>
pub fn with_esdt_transfer<P: Into<EsdtTokenPayment<SA>>>( self, payment: P, ) -> ContractCallWithMultiEsdt<SA, OriginalResult>
Adds a single ESDT token transfer to a contract call.
Can be called multiple times on the same call.
pub fn add_esdt_token_transfer( self, payment_token: EsdtTokenIdentifier<SA>, payment_nonce: u64, payment_amount: BigUint<SA>, ) -> ContractCallWithMultiEsdt<SA, OriginalResult>
Replace by contract_call.with_esdt_transfer((payment_token, payment_nonce, payment_amount)).
The tuple argument will get automatically converted to EsdtTokenPayment.
Sourcepub fn with_multi_token_transfer(
self,
payments: ManagedVec<SA, EsdtTokenPayment<SA>>,
) -> ContractCallWithMultiEsdt<SA, OriginalResult>
pub fn with_multi_token_transfer( self, payments: ManagedVec<SA, EsdtTokenPayment<SA>>, ) -> ContractCallWithMultiEsdt<SA, OriginalResult>
Sets payment to be a (potentially) multi-token transfer.
Sourcepub fn with_any_payment(
self,
payment: EgldOrMultiEsdtPayment<SA>,
) -> ContractCallWithAnyPayment<SA, OriginalResult>
pub fn with_any_payment( self, payment: EgldOrMultiEsdtPayment<SA>, ) -> ContractCallWithAnyPayment<SA, OriginalResult>
Sets payment to be a (potentially) multi-token transfer.
Sourcepub fn with_egld_or_single_esdt_transfer<P: Into<EgldOrEsdtTokenPayment<SA>>>(
self,
payment: P,
) -> ContractCallWithEgldOrSingleEsdt<SA, OriginalResult>
pub fn with_egld_or_single_esdt_transfer<P: Into<EgldOrEsdtTokenPayment<SA>>>( self, payment: P, ) -> ContractCallWithEgldOrSingleEsdt<SA, OriginalResult>
Sets payment to be either EGLD or a single ESDT transfer, as determined at runtime.
pub fn with_egld_or_single_esdt_token_transfer( self, payment_token: EgldOrEsdtTokenIdentifier<SA>, payment_nonce: u64, payment_amount: BigUint<SA>, ) -> ContractCallWithEgldOrSingleEsdt<SA, OriginalResult>
Replace by contract_call.with_egld_or_single_esdt_transfer((payment_token, payment_nonce, payment_amount)).
pub fn into_function_call(self) -> FunctionCall<SA>
pub fn tx(self) -> Tx<TxScEnv<SA>, (), (), (), (), FunctionCall<SA>, ()>