pub struct ContractCallWithEgld<SA, OriginalResult>where
SA: CallTypeApi + 'static,{
pub basic: ContractCallNoPayment<SA, OriginalResult>,
pub egld_payment: BigUint<SA>,
}Please use the unified transaction syntax instead.
Holds data for calling another contract, with EGLD payment only.
Gets created when chaining method with_egld_transfer.
If the payment is zero, it bevahes exactly like ContractCallNoPayment.
It also represents the normalized form of any contract call, since ESDT transfers (the only payment not available here) get converted to builtin function calls in normalized form.
Fields
basic: ContractCallNoPayment<SA, OriginalResult>Please use the unified transaction syntax instead.
egld_payment: BigUint<SA>Please use the unified transaction syntax instead.
Implementations
Sourceimpl<SA, OriginalResult> ContractCallWithEgld<SA, OriginalResult>where
SA: CallTypeApi + 'static,
impl<SA, OriginalResult> ContractCallWithEgld<SA, OriginalResult>where
SA: CallTypeApi + 'static,
Sourcepub fn convert_to_esdt_transfer_call(
self,
payments: ManagedVec<SA, EsdtTokenPayment<SA>>,
) -> Self
pub fn convert_to_esdt_transfer_call( self, payments: ManagedVec<SA, EsdtTokenPayment<SA>>, ) -> Self
If this is an ESDT call, it converts it to a regular call to ESDTTransfer.
Async calls require this step, but not transfer_esdt_execute.
Sourceimpl<SA, OriginalResult> ContractCallWithEgld<SA, OriginalResult>where
SA: CallTypeApi + 'static,
impl<SA, OriginalResult> ContractCallWithEgld<SA, OriginalResult>where
SA: CallTypeApi + 'static,
pub fn resolve_gas_limit(&self) -> u64
pub fn get_back_transfers( &self, ) -> (BigUint<SA>, ManagedVec<SA, EsdtTokenPayment<SA>>)
pub fn to_call_data_string(&self) -> ManagedBuffer<SA>
Sourceimpl<SA, OriginalResult> ContractCallWithEgld<SA, OriginalResult>where
SA: CallTypeApi + 'static,
impl<SA, OriginalResult> ContractCallWithEgld<SA, OriginalResult>where
SA: CallTypeApi + 'static,
Sourcepub fn new<N: Into<ManagedBuffer<SA>>>(
to: ManagedAddress<SA>,
endpoint_name: N,
egld_payment: BigUint<SA>,
) -> Self
pub fn new<N: Into<ManagedBuffer<SA>>>( to: ManagedAddress<SA>, endpoint_name: N, egld_payment: BigUint<SA>, ) -> Self
Creates a new instance directly.
The constructor is mostly for hand-written proxies,
the usual way of constructing this object is via the builder methods of other contract call types,
especially with_egld_transfer.