pub struct ContractCallWithMultiEsdt<SA, OriginalResult>where
SA: CallTypeApi + 'static,{
pub basic: ContractCallNoPayment<SA, OriginalResult>,
pub esdt_payments: ManagedVec<SA, EsdtTokenPayment<SA>>,
}Please use the unified transaction syntax instead.
Fields
basic: ContractCallNoPayment<SA, OriginalResult>Please use the unified transaction syntax instead.
esdt_payments: ManagedVec<SA, EsdtTokenPayment<SA>>Please use the unified transaction syntax instead.
Implementations
Sourceimpl<SA, OriginalResult> ContractCallWithMultiEsdt<SA, OriginalResult>where
SA: CallTypeApi + 'static,
impl<SA, OriginalResult> ContractCallWithMultiEsdt<SA, OriginalResult>where
SA: CallTypeApi + 'static,
Sourcepub fn new<N: Into<ManagedBuffer<SA>>>(
to: ManagedAddress<SA>,
endpoint_name: N,
payments: ManagedVec<SA, EsdtTokenPayment<SA>>,
) -> Self
pub fn new<N: Into<ManagedBuffer<SA>>>( to: ManagedAddress<SA>, endpoint_name: N, payments: ManagedVec<SA, EsdtTokenPayment<SA>>, ) -> Self
Creates a new instance directly.
The constructor is mostly for hand-written proxies,
the usual way of constructing this object is via the builder methods of other contract call types,
especially with_esdt_transfer or with_multi_token_transfer.
Sourcepub fn with_esdt_transfer<P: Into<EsdtTokenPayment<SA>>>(
self,
payment: P,
) -> Self
pub fn with_esdt_transfer<P: Into<EsdtTokenPayment<SA>>>( self, payment: P, ) -> Self
Adds a single ESDT token transfer to a contract call.
Can be called multiple times on the same call.
pub fn add_esdt_token_transfer( self, payment_token: EsdtTokenIdentifier<SA>, payment_nonce: u64, payment_amount: BigUint<SA>, ) -> Self
Replace by contract_call.with_esdt_transfer((payment_token, payment_nonce, payment_amount)).
The tuple argument will get automatically converted to EsdtTokenPayment.