pub struct GasLeft;Expand description
Indicates that all remaining gas should be sent to a transaction.
Usually unwise, other than for synchronous calls, you always want to have some gas left in the contract after the call.