pub struct ScenarioPayments<Api>where
Api: ManagedTypeApi,{
pub egld: Option<AnnotatedEgldPayment<Api>>,
pub multi_esdt: PaymentVec<Api>,
}Expand description
Intermediate representation for generating payments in tx steps in scenarios.
It traces back to the Mandos payment syntax, either "egldValue": "..." or "esdtValue": [...].
Fields
egld: Option<AnnotatedEgldPayment<Api>>multi_esdt: PaymentVec<Api>Trait Implementations
Sourceimpl<Api> Clone for ScenarioPayments<Api>where
Api: ManagedTypeApi + Clone,
impl<Api> Clone for ScenarioPayments<Api>where
Api: ManagedTypeApi + Clone,
Sourcefn clone(&self) -> ScenarioPayments<Api>
fn clone(&self) -> ScenarioPayments<Api>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<Api> Default for ScenarioPayments<Api>where
Api: ManagedTypeApi,
impl<Api> Default for ScenarioPayments<Api>where
Api: ManagedTypeApi,