TestTokenId

Struct TestTokenId 

pub struct TestTokenId<'a> { /* private fields */ }
Encodes a dummy address, to be used for tests.

It is designed to be usable from contracts (especially test contracts), with a minimal footprint. For this reason, its inner structure is subject to change.

Implementations

Source

impl<'a> TestTokenId<'a>

pub const EGLD_000000: TestTokenId<'static>

A constant representing the EGLD-000000 token identifier.

pub const fn new(name: &'a str) -> Self

Creates a new test token identifier from a string name.

pub fn eval_to_expr(&self) -> String

Evaluates the test token identifier to a Mandos (scenario) expression string with the “str:” prefix.

pub fn to_token_identifier<Api: ManagedTypeApi>( &self, ) -> EsdtTokenIdentifier<Api>

👎Deprecated since 0.65.0: Use to_esdt_token_identifier() instead

Incorrectly named method, kept for backward compatibility.

Use:

  • into/from for direct conversion to TokenId;
  • [to_token_id()] - to explicitly convert to TokenId;
  • [to_esdt_token_identifier()] - for ESDT-only scenarios, mostly legacy.
pub fn to_esdt_token_identifier<Api: ManagedTypeApi>( &self, ) -> EsdtTokenIdentifier<Api>

Converts this test token identifier to an ESDT token identifier.

Use this for ESDT-only scenarios, mostly legacy code.

pub fn to_token_id<Api: ManagedTypeApi>(&self) -> TokenId<Api>

Converts this test token identifier to a TokenId.

pub fn as_str(&self) -> &str

Returns the token identifier name as a string slice.

pub fn as_bytes(&self) -> &[u8]

Returns the token identifier name as a byte slice.