IgnoreVarArgs

Type Alias IgnoreVarArgs 

pub type IgnoreVarArgs = IgnoreValue;
๐Ÿ‘ŽDeprecated since 0.29.0:

Alias kept for backwards compatibility. Replace with IgnoreValue

Structure that allows taking a variable number of arguments, but does nothing with them, not even deserialization.

Aliased Type

pub struct IgnoreVarArgs;