pub struct TypeAbiUniversalInput<T> { /* private fields */ }Expand description
Type that ignores TypeAbiFrom restrictions.
Can be used to pass values to any argument, in any endpoint, regardless of type.
The any value type can be used, as long as it can be encoded. Typically it is used with BytesValue, when converting from Mandos scenarios.
Implementations