Structs
- Linear
Interpolation Invalid Values Error - Error returned when
current_inis outside the[min_in, max_in]range.
Functions
- linear_
interpolation - Computes a linearly interpolated output value for a given input within a known range.
- weighted_
average - Computes the weighted average of two values.
- weighted_
average_ round_ up - Computes the weighted average of two values, rounded up (ceiling division).